import { ApplySchemaAttributes, CommandFunction, CreateExtensionPlugin, Helper, MarkExtension, MarkExtensionSpec, MarkSpecOverride, PrimitiveSelection, ProsemirrorNode } from '@remirror/core';
import { EntityReferenceMetaData, EntityReferenceOptions } from './types';
interface EntityReferenceState {
    entityReferences: {
        [key: string]: any;
    };
}
export declare class EntityReferenceExtension extends MarkExtension<EntityReferenceOptions> {
    get name(): string;
    createMarkSpec(extra: ApplySchemaAttributes, override: MarkSpecOverride): MarkExtensionSpec;
    /**
     * Create the extension plugin for inserting decorations into the editor.
     */
    createPlugin(): CreateExtensionPlugin<EntityReferenceState>;
    addEntityReference(id?: string): CommandFunction;
    removeEntityReference(entityReferenceId: string): CommandFunction;
    /**
     * Get all disjoined entityReference attributes from the document.
     */
    getDisjoinedEntityReferences(doc: ProsemirrorNode): Helper<EntityReferenceMetaData[][]>;
    /**
     * Disjoined entityReferences are analog to ProseMirror's marks. When adding a mark
     * that spans two (or more) nodes (like paragraphs), it will be stored as two
     * (or more) marks on each node separately. The same is true for disjoined
     * entityReferences. Therefore, a entityReference that spans multiple paragraphs is
     * internally stored as multiple marks (all having the same entityReference ID as
     * attribute).
     *
     * To get the actual entityReferences (for which each entityReference ID is unique), call
     * `joinDisjoinedEntityReferences`.
     */
    getEntityReferences(): Helper<EntityReferenceMetaData[]>;
    /**
     * @param pos - the position in the root document to find entityReference marks.
     *
     * @returns all entityReferences at a specific position in the editor.
     *
     */
    getEntityReferencesAt(pos?: PrimitiveSelection): Helper<EntityReferenceMetaData[]>;
}
export {};
